function MapFov()
{
  this.map = null;
  this.angle = 0;
  this.viewAngle = 0;
  this.center = new google.maps.LatLng(0, 0);
  this.mapZoom = 1;
  this.size = 1.0;
  
  this.polyline = new google.maps.Polyline({
    path: [],
    geodesic: false,
    strokeColor: '#5555FF',
    strokeOpacity: 0.8,
    strokeWeight: 2
  });
};

MapFov.prototype.setMap = function( map )
{
  this.map = map;
  this.polyline.setMap( map );
  this.mapZoom = map.getZoom();
  var objFov = this;
  google.maps.event.addListener(map, 'zoom_changed', function() {
     objFov.mapZoom = map.getZoom();
     objFov.updateGeometry();
  });

  this.updateGeometry();
};

MapFov.prototype.setCenter = function( lat, lon )
{
  this.center = new google.maps.LatLng(lat, lon);
  this.updateGeometry();
};

MapFov.prototype.setRotation = function( deg )
{
  this.angle = deg;
  this.updateGeometry();
};

MapFov.prototype.setFov = function( deg )
{
  this.viewAngle = deg;
  this.updateGeometry();
};

MapFov.prototype.setSize = function( size )
{
  this.size = size;
  this.updateGeometry();
};

MapFov.prototype.updateGeometry = function()
{
  var pathCoords = [
    new google.maps.LatLng(
      this.center.lat() + Math.cos( ( this.angle - this.viewAngle * 0.5 ) / 57.3 ) * this.size * 100.0 / Math.pow( 2, this.mapZoom), 
      this.center.lng() - Math.sin( ( this.angle - this.viewAngle * 0.5 ) / 57.3 ) / Math.cos( this.center.lat() / 57.3 ) * this.size * 100.0 / Math.pow( 2, this.mapZoom) ),
    this.center,
    new google.maps.LatLng(
      this.center.lat() + Math.cos( ( this.angle * 1.0 + this.viewAngle * 0.5 ) / 57.3 ) * this.size * 100.0 / Math.pow( 2, this.mapZoom),
      this.center.lng() - Math.sin( ( this.angle * 1.0 + this.viewAngle * 0.5 ) / 57.3 ) / Math.cos( this.center.lat() / 57.3 ) * this.size * 100.0 / Math.pow( 2, this.mapZoom) )
  ];
  this.polyline.setPath( pathCoords );
};